Crate rinia

Crate rinia 

Re-exports

pub use self::quaternion::Quat;
pub use self::quaternion::Quatd;
pub use self::quaternion::Quaternion;
pub use self::quaternion::Quatf;
pub use self::scalar::Float;
pub use self::scalar::Int;
pub use self::scalar::Scalar;
pub use self::scalar::Scalard;
pub use self::scalar::Scalarf;
pub use self::scalar::Signed;
pub use self::scalar::SignedInt;
pub use self::scalar::Unsigned;
pub use self::scalar::UnsignedInt;
pub use self::vector::Vec2;
pub use self::vector::Vec2d;
pub use self::vector::Vec2f;
pub use self::vector::Vec3;
pub use self::vector::Vec3d;
pub use self::vector::Vec3f;
pub use self::vector::Vec4;
pub use self::vector::Vec4d;
pub use self::vector::Vec4f;
pub use self::vector::Vector;

Modules

algebra
external
numeric
prelude
quaternion
scalar
tuple
vector

Macros

approx_eq_abs
Returns whether two values are approximately equal using ApproxEqAbs. Pass a third argument to override the default absolute tolerance.
approx_eq_rel
Returns whether two values are approximately equal using ApproxEqRel. Pass a third argument to override the default relative tolerance.
approx_ne_abs
Returns whether two values are not approximately equal using ApproxEqAbs. Pass a third argument to override the default absolute tolerance.
approx_ne_rel
Returns whether two values are not approximately equal using ApproxEqRel. Pass a third argument to override the default relative tolerance.
assert_approx_eq_abs
Asserts that two values are approximately equal using ApproxEqAbs. Pass a third argument to override the default absolute tolerance, or message = ... to provide a custom assertion message while using the default tolerance.
assert_approx_eq_rel
Asserts that two values are approximately equal using ApproxEqRel. Pass a third argument to override the default relative tolerance, or message = ... to provide a custom assertion message while using the default tolerance.
assert_approx_ne_abs
Asserts that two values are not approximately equal using ApproxEqAbs. Pass a third argument to override the default absolute tolerance, or message = ... to provide a custom assertion message while using the default tolerance.
assert_approx_ne_rel
Asserts that two values are not approximately equal using ApproxEqRel. Pass a third argument to override the default relative tolerance, or message = ... to provide a custom assertion message while using the default tolerance.
impl_approx_eq_wrapper
Implements approximate-equality surfaces for wrapper types.
impl_numeric_casts_wrapper
Implements numeric cast surfaces for thin/thick wrapper types.