Quat

Struct Quat 

#[repr(C)]
pub struct Quat<T: QuatScalar> { pub x: T, pub y: T, pub z: T, pub w: T, }
A quaternion type, representing a rotation in 3D space.

Fields

x: T

The x component of the quaternion.

y: T

The y component of the quaternion.

z: T

The z component of the quaternion.

w: T

The w component of the quaternion.

Implementations

Source

impl<T: QuatScalar> Quat<T>

pub const IDENTITY: Self

The identity quaternion, representing no rotation.

pub const fn new(x: T, y: T, z: T, w: T) -> Self

Creates a new quaternion with the given components.

Source

impl<T> Quat<T>
where T: QuatScalar,

pub const fn splat(scalar: T) -> Self

Creates a new instance of the tuple type with all elements set to the given scalar value.

pub const fn as_ptr(&self) -> *const T

Returns a raw pointer to the first element of the tuple.

pub const fn as_mut_ptr(&mut self) -> *mut T

Returns a mutable raw pointer to the first element of the tuple.

pub const fn as_slice(&self) -> &[T]

Returns a slice containing all elements of the tuple.

pub const fn as_mut_slice(&mut self) -> &mut [T]

Returns a mutable slice containing all elements of the tuple.

pub const fn to_array(self) -> [T; 4]

Converts the tuple into an array of its scalar elements.

pub const fn from_array(a: [T; 4]) -> Self

Creates a new instance of the tuple type from an array of scalar elements.

Source

impl<T> Quat<T>
where T: QuatScalar,

pub fn dot(self, rhs: Self) -> T