Vec4

Struct Vec4 

#[repr(C)]
pub struct Vec4<T: VectorScalar> { pub x: T, pub y: T, pub z: T, pub w: T, }
A 4D vector.

Fields

x: T

The x component of the vector.

y: T

The y component of the vector.

z: T

The z component of the vector.

w: T

The w component of the vector.

Implementations

Source

impl<T: VectorScalar> Vec4<T>

pub const fn new(x: T, y: T, z: T, w: T) -> Self

Creates a new vector with the given components.

Source

impl<T> Vec4<T>
where T: VectorScalar,

pub const fn splat(scalar: T) -> Self

Creates a new instance of the tuple type with all elements set to the given scalar value.

pub const fn as_ptr(&self) -> *const T

Returns a raw pointer to the first element of the tuple.

pub const fn as_mut_ptr(&mut self) -> *mut T

Returns a mutable raw pointer to the first element of the tuple.

pub const fn as_slice(&self) -> &[T]

Returns a slice containing all elements of the tuple.

pub const fn as_mut_slice(&mut self) -> &mut [T]

Returns a mutable slice containing all elements of the tuple.

pub const fn to_array(self) -> [T; 4]

Converts the tuple into an array of its scalar elements.

pub const fn from_array(a: [T; 4]) -> Self

Creates a new instance of the tuple type from an array of scalar elements.

Source

impl<T> Vec4<T>
where T: VectorScalar,

pub fn dot(self, rhs: Self) -> T

Source

impl<T> Vec4<T>
where T: VectorScalar + Select,

pub fn min(self, other: Self) -> Self

Returns a vector containing the minimum values of each component of self and other.

pub fn max(self, other: Self) -> Self

Returns a vector containing the maximum values of each component of self and other.

Source

impl<T> Vec4<T>
where T: VectorScalar + Neg<Output = T>,

pub fn negate(self) -> Self

Negates each component of the vector and returns a new vector.

Source

impl<T> Vec4<T>
where T: VectorScalar,

pub const ZERO: Self

Returns a vector with all components set to the additive identity (zero).

pub fn is_zero(self) -> bool

Checks if all components of the vector are equal to the additive identity (zero).

Source

impl<T> Vec4<T>
where T: VectorScalar,

pub const ONE: Self

Returns a vector with all components set to the multiplicative identity (one).