Re-exports
pub use self::quaternion::Quat;pub use self::quaternion::Quatd;pub use self::quaternion::Quaternion;pub use self::quaternion::Quatf;pub use self::scalar::Float;pub use self::scalar::Int;pub use self::scalar::Scalar;pub use self::scalar::Scalard;pub use self::scalar::Scalarf;pub use self::scalar::Signed;pub use self::scalar::SignedInt;pub use self::scalar::Unsigned;pub use self::scalar::UnsignedInt;pub use self::vector::Vec2;pub use self::vector::Vec2d;pub use self::vector::Vec2f;pub use self::vector::Vec3;pub use self::vector::Vec3d;pub use self::vector::Vec3f;pub use self::vector::Vec4;pub use self::vector::Vec4d;pub use self::vector::Vec4f;pub use self::vector::Vector;
Modules
Macros
- approx_
eq_ abs - Returns whether two values are approximately equal using
ApproxEqAbsand the type’s default absolute tolerance. - approx_
eq_ abs_ tol - Returns whether two values are approximately equal using
ApproxEqAbsand an explicit absolute tolerance. - approx_
eq_ rel - Returns whether two values are approximately equal using
ApproxEqReland the type’s default relative tolerance. - approx_
eq_ rel_ tol - Returns whether two values are approximately equal using
ApproxEqReland an explicit relative tolerance. - approx_
ne_ abs - Returns whether two values are not approximately equal using
ApproxEqAbsand the type’s default absolute tolerance. - approx_
ne_ abs_ tol - Returns whether two values are not approximately equal using
ApproxEqAbsand an explicit absolute tolerance. - approx_
ne_ rel - Returns whether two values are not approximately equal using
ApproxEqReland the type’s default relative tolerance. - approx_
ne_ rel_ tol - Returns whether two values are not approximately equal using
ApproxEqReland an explicit relative tolerance. - assert_
approx_ eq_ abs - Asserts that two values are approximately equal using
ApproxEqAbsand the type’s default absolute tolerance. - assert_
approx_ eq_ abs_ tol - Asserts that two values are approximately equal using
ApproxEqAbsand an explicit absolute tolerance. - assert_
approx_ eq_ rel - Asserts that two values are approximately equal using
ApproxEqReland the type’s default relative tolerance. - assert_
approx_ eq_ rel_ tol - Asserts that two values are approximately equal using
ApproxEqReland an explicit relative tolerance. - assert_
approx_ ne_ abs - Asserts that two values are not approximately equal using
ApproxEqAbsand the type’s default absolute tolerance. - assert_
approx_ ne_ abs_ tol - Asserts that two values are not approximately equal using
ApproxEqAbsand an explicit absolute tolerance. - assert_
approx_ ne_ rel - Asserts that two values are not approximately equal using
ApproxEqReland the type’s default relative tolerance. - assert_
approx_ ne_ rel_ tol - Asserts that two values are not approximately equal using
ApproxEqReland an explicit relative tolerance.