#[repr(C)]pub struct Quat<T: QuatScalar> {
pub x: T,
pub y: T,
pub z: T,
pub w: T,
}Expand description
A quaternion type, representing a rotation in 3D space.
Fields
x: TThe x component of the quaternion.
y: TThe y component of the quaternion.
z: TThe z component of the quaternion.
w: TThe w component of the quaternion.
Implementations
Sourceimpl<T: QuatScalar> Quat<T>
impl<T: QuatScalar> Quat<T>
Sourceimpl<T> Quat<T>where
T: QuatScalar,
impl<T> Quat<T>where
T: QuatScalar,
Sourcepub const fn splat(scalar: T) -> Self
pub const fn splat(scalar: T) -> Self
Creates a new instance of the tuple type with all elements set to the given scalar value.
Sourcepub const fn as_ptr(&self) -> *const T
pub const fn as_ptr(&self) -> *const T
Returns a raw pointer to the first element of the tuple.
Sourcepub const fn as_mut_ptr(&mut self) -> *mut T
pub const fn as_mut_ptr(&mut self) -> *mut T
Returns a mutable raw pointer to the first element of the tuple.
Sourcepub const fn as_mut_slice(&mut self) -> &mut [T]
pub const fn as_mut_slice(&mut self) -> &mut [T]
Returns a mutable slice containing all elements of the tuple.
Sourcepub const fn from_array(a: [T; 4]) -> Self
pub const fn from_array(a: [T; 4]) -> Self
Creates a new instance of the tuple type from an array of scalar elements.