#[repr(C)]pub struct Vec4<T: VectorScalar> {
pub x: T,
pub y: T,
pub z: T,
pub w: T,
}Expand description
A 4D vector.
Fields
x: TThe x component of the vector.
y: TThe y component of the vector.
z: TThe z component of the vector.
w: TThe w component of the vector.
Implementations
Sourceimpl<T: VectorScalar> Vec4<T>
impl<T: VectorScalar> Vec4<T>
Sourceimpl<T> Vec4<T>where
T: VectorScalar,
impl<T> Vec4<T>where
T: VectorScalar,
Sourcepub const fn splat(scalar: T) -> Self
pub const fn splat(scalar: T) -> Self
Creates a new instance of the tuple type with all elements set to the given scalar value.
Sourcepub const fn as_ptr(&self) -> *const T
pub const fn as_ptr(&self) -> *const T
Returns a raw pointer to the first element of the tuple.
Sourcepub const fn as_mut_ptr(&mut self) -> *mut T
pub const fn as_mut_ptr(&mut self) -> *mut T
Returns a mutable raw pointer to the first element of the tuple.
Sourcepub const fn as_mut_slice(&mut self) -> &mut [T]
pub const fn as_mut_slice(&mut self) -> &mut [T]
Returns a mutable slice containing all elements of the tuple.
Sourcepub const fn from_array(a: [T; 4]) -> Self
pub const fn from_array(a: [T; 4]) -> Self
Creates a new instance of the tuple type from an array of scalar elements.
Sourceimpl<T> Vec4<T>where
T: VectorScalar + Select,
impl<T> Vec4<T>where
T: VectorScalar + Select,
Sourceimpl<T> Vec4<T>where
T: VectorScalar + Neg<Output = T>,
impl<T> Vec4<T>where
T: VectorScalar + Neg<Output = T>,
Sourceimpl<T> Vec4<T>where
T: VectorScalar,
impl<T> Vec4<T>where
T: VectorScalar,